@@ -23,14 +23,13 @@
 #include <config.h>
 
 #include <stdlib.h>
+#include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <games-conf.h>
-#include <games-stock.h>
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 
 #include "blackjack.h"
 #include "events.h"
@@ -84,7 +83,6 @@ gboolean show_toolbar = TRUE;
 gchar *game_variation = NULL;
 
 #define DEFAULT_VARIATION      "Vegas_Strip.rules"
-#define DEFAULT_THEME "bonded"
 
 void
 bj_make_window_title (gchar *game_name) 
@@ -182,12 +180,13 @@ fullscreen_cb (GtkAction *action)
 }
 
 /* Just in case something else takes us to/from fullscreen. */
-static void 
+static gboolean
 window_state_cb (GtkWidget *widget, GdkEventWindowState *event)
 {
 	if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
         	set_fullscreen_actions (event->new_window_state &
 					GDK_WINDOW_STATE_FULLSCREEN);
+	return FALSE;
 }
 
 
@@ -231,7 +230,7 @@ bj_quit_app (void)
 
         bj_slot_free_pixmaps ();
         g_object_unref (surface);
-        g_object_unref (press_data->moving_cards);
+        gdk_window_destroy (press_data->moving_cards);
 
         gtk_widget_destroy (toplevel_window);
         gtk_main_quit ();
@@ -281,7 +280,6 @@ create_main_window (void)
         GtkWidget    *group_box;
         GtkWidget    *label;
         GError       *error       = NULL;
-        gint          width, height;
         char         *label_string;
         GtkActionGroup *actions;
 
@@ -439,8 +437,6 @@ create_main_window (void)
 static void
 main_prog (void)
 {
-        gchar *lcard_style;
-        gchar *label_string;
         guint context_id;
 
         create_main_window ();
@@ -519,20 +515,17 @@ bj_get_card_style ()
 {
         gchar *lcard_style;
 
-        lcard_style = games_conf_get_string_with_default (KEY_DECK_GROUP,
-                                                          KEY_CARD_STYLE,
-                                                          DEFAULT_THEME);
-        /* Back compat */
-        if (g_str_has_suffix (lcard_style, ".svg"))
-                *g_strrstr (lcard_style, ".svg") = '\0';
-        else if (g_str_has_suffix (lcard_style, ".png"))
-                *g_strrstr (lcard_style, ".png") = '\0';
+        lcard_style = games_conf_get_string (KEY_DECK_GROUP, KEY_CARD_STYLE, NULL);
+        if (!lcard_style || !lcard_style[0]) {
+                g_free (lcard_style);
+		lcard_style = NULL;
+        }
 
         return lcard_style;
 }
 
 void
-bj_set_card_style (gchar *value)
+bj_set_card_style (const char *value)
 {
         games_conf_set_string (KEY_DECK_GROUP, KEY_CARD_STYLE, value);
 }
@@ -583,18 +576,24 @@ bj_set_never_insurance (gboolean value)
         games_conf_set_boolean (KEY_SETTINGS_GROUP, KEY_NEVER_INSURANCE, value);
 }
 
-gchar *
+const gchar *
 bj_get_game_variation ()
 {
-        return g_strdup (game_variation);
+        return game_variation;
 }
 
 void
 bj_set_game_variation (const gchar *value)
 {
-        if (game_variation)
-                g_free (game_variation);
+        char *old_value;
+
+        if (value == game_variation)
+                return;
+
+        old_value = game_variation;
         game_variation = g_strdup (value);
+        g_free (old_value);
+
         games_conf_set_string (KEY_SETTINGS_GROUP, KEY_GAME_VARIATION, game_variation);
 }
 
@@ -660,16 +659,8 @@ main (int argc, char *argv [])
                 { NULL }
         };
 
-        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-        textdomain (GETTEXT_PACKAGE);
-
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
+        if (!games_runtime_init ("blackjack"))
+                return 1;
 
         context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
@@ -677,16 +668,6 @@ main (int argc, char *argv [])
 #endif
         g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 
-
-#ifdef HAVE_GNOME
-        GnomeProgram *program;
-        program = gnome_program_init ("Blackjack", VERSION,
-                                      LIBGNOMEUI_MODULE,
-                                      argc, argv,
-                                      GNOME_PARAM_GOPTION_CONTEXT, context,
-                                      GNOME_PARAM_APP_DATADIR, DATADIR,
-                                      NULL);
-#else
         g_option_context_add_group (context, gtk_get_option_group (TRUE));
         retval = g_option_context_parse (context, &argc, &argv, &error);
         if (!retval) {
@@ -694,7 +675,6 @@ main (int argc, char *argv [])
                 g_error_free (error);
                 goto cleanup;
         }
-#endif
 
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
@@ -707,7 +687,7 @@ main (int argc, char *argv [])
         bj_conf_init ();
 
         if (!variation)
-                variation = game_variation;
+                variation = g_strdup (game_variation);
 
         bj_game_find_rules (variation);
 
@@ -719,9 +699,7 @@ main (int argc, char *argv [])
 
         games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-        g_object_unref (program);
-#endif
+        games_runtime_shutdown ();
 
         return 0;
 }
