@@ -268,6 +268,7 @@ games_stock_init (void)
     { GAMES_STOCK_CONTENTS,         GTK_STOCK_HELP },
     { GAMES_STOCK_HINT,             GTK_STOCK_DIALOG_INFO },
     { GAMES_STOCK_NEW_GAME,         GTK_STOCK_NEW },
+    { GAMES_STOCK_START_NEW_GAME,   GTK_STOCK_NEW },
     { GAMES_STOCK_RESET,            GTK_STOCK_CLEAR },
     { GAMES_STOCK_RESTART_GAME,     GTK_STOCK_REFRESH },
 #if GTK_CHECK_VERSION (2, 8, 0)
@@ -419,9 +420,14 @@ games_get_license_version (const gchar * game_name,
     N_("You should have received a copy of the GNU General Public License "
        "along with %s; if not, write to the Free Software Foundation, Inc., "
        "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA");
+  static const char license3[] =
+    N_("You should have received a copy of the GNU General Public License "
+       "along with this program.  If not, see <http://www.gnu.org/licenses/>.");
 
-  license_trans = g_strjoin ("\n\n", _(license0), _(license1),
-                             _(license2), NULL);
+  if (version >= 3)
+    license_trans = g_strjoin ("\n\n", _(license0), _(license1), _(license3), NULL);
+  else
+    license_trans = g_strjoin ("\n\n", _(license0), _(license1), _(license2), NULL);
 
 #if !GTK_CHECK_VERSION (2, 8, 0)
   /* We have to manually wrap the text, since the about dialogue cannot
